@@ -13,7 +13,6 @@ from executorlib.shared.inputcheck import (
     check_refresh_rate,
     check_resource_dict,
     check_resource_dict_is_empty,
-    validate_backend,
 )
 
 
@@ -38,26 +37,6 @@ class TestInputCheck(unittest.TestCase):
         with self.assertRaises(ValueError):
             check_executor(executor=1)
 
-    def test_check_backend(self):
-        with self.assertRaises(ValueError):
-            validate_backend(
-                backend="test", flux_installed=False, slurm_installed=False
-            )
-        with self.assertRaises(ImportError):
-            validate_backend(
-                backend="flux", flux_installed=False, slurm_installed=False
-            )
-        with self.assertRaises(RuntimeError):
-            validate_backend(
-                backend="slurm", flux_installed=False, slurm_installed=False
-            )
-        self.assertEqual(
-            validate_backend(
-                backend="slurm", flux_installed=False, slurm_installed=True
-            ),
-            "slurm",
-        )
-
     def test_check_init_function(self):
         with self.assertRaises(ValueError):
             check_init_function(init_function=1, block_allocation=False)
